// Copyright 2024 Martin Riedl
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// 	http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package gomp4

// MediaInformationBox media information box struct
// 8.4.4 Media Information Box
//
// Box Type: ‘minf’
// Container: Media Box (‘mdia’)
// Mandatory: Yes
// Quantity: Exactly one
//
// This box contains all the objects that declare characteristic information of the media in the track.
type MediaInformationBox struct {
	*Box
	ChildBoxes []interface{}
}

// ParseMediaInformationBox creates a new media information box struct based on bytes
func ParseMediaInformationBox(filePosition uint64, headerSize uint32, content []byte) (*MediaBox, error) {
	box := &MediaBox{Box: &Box{filePosition, headerSize}}

	// parse child boxes
	var err error
	box.ChildBoxes, err = box.parseChildBoxes(filePosition, content)
	return box, err
}
